@@ -1,7 +1,7 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2009 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2009-2014 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
@@ -27,13 +27,15 @@
 #include "cmd.h"
 #include "project.h"
 
-#include <klocale.h>
-#include <krun.h>
 #include <QContextMenuEvent>
 #include <QMenu>
-#include <kfiledialog.h>
-#include <kdirwatch.h>
+#include <QFileDialog>
 
+#include <klocalizedstring.h>
+#ifndef NOKDE
+#include <krun.h>
+#include <kdirwatch.h>
+#endif
 
 //BEGIN BinUnitsModel
 BinUnitsModel::BinUnitsModel(Catalog* catalog, QObject* parent)
@@ -42,14 +44,16 @@ BinUnitsModel::BinUnitsModel(Catalog* catalog, QObject* parent)
 {
     connect(catalog,SIGNAL(signalFileLoaded()),this,SLOT(fileLoaded()));
     connect(catalog,SIGNAL(signalEntryModified(DocPosition)),this,SLOT(entryModified(DocPosition)));
-
+#ifndef NOKDE
     connect(KDirWatch::self(),SIGNAL(dirty(QString)),this,SLOT(updateFile(QString)));
+#endif
 }
 
 void BinUnitsModel::fileLoaded()
 {
+    beginResetModel();
     m_imageCache.clear();
-    reset();
+    endResetModel();
 }
 
 void BinUnitsModel::entryModified(const DocPosition& pos)
@@ -63,13 +67,12 @@ void BinUnitsModel::entryModified(const DocPosition& pos)
 
 void BinUnitsModel::updateFile(QString path)
 {
-    QString relPath=KUrl::relativePath(Project::instance()->projectDir(),path);
+    QString relPath=QDir(Project::instance()->projectDir()).relativeFilePath(path);
 
     DocPosition pos(m_catalog->numberOfEntries());
     int limit=m_catalog->numberOfEntries()+m_catalog->binUnitsCount();
     while (pos.entry<limit)
     {
-        kWarning()<<m_catalog->target(pos);
         if (m_catalog->target(pos)==relPath || m_catalog->source(pos)==relPath)
         {
             int row=pos.entry-m_catalog->numberOfEntries();
@@ -92,7 +95,7 @@ void BinUnitsModel::setTargetFilePath(int row, const QString& path)
         m_imageCache.remove(old);
     }
 
-    m_catalog->push(new InsTextCmd(m_catalog, pos, KUrl::relativePath(Project::instance()->projectDir(),path)));
+    m_catalog->push(new InsTextCmd(m_catalog, pos, QDir(Project::instance()->projectDir()).relativeFilePath(path)));
     QModelIndex item=index(row,TargetFilePath);
     emit dataChanged(item,item);
 }
@@ -115,7 +118,9 @@ QVariant BinUnitsModel::data(const QModelIndex& index, int role) const
             if (!m_imageCache.contains(path))
             {
                 QString absPath=Project::instance()->absolutePath(path);
+#ifndef NOKDE
                 KDirWatch::self()->addFile(absPath); //TODO remember watched files to react only on them in dirty() signal handler
+#endif
                 m_imageCache.insert(path, QImage(absPath).scaled(128,128,Qt::KeepAspectRatio));
             }
             return m_imageCache.value(path);
@@ -160,7 +165,7 @@ BinUnitsView::BinUnitsView(Catalog* catalog, QWidget* parent)
  , m_model(new BinUnitsModel(catalog, this))
  , m_view(new MyTreeView(this))
 {
-    setObjectName("binUnits");
+    setObjectName(QStringLiteral("binUnits"));
     hide();
 
     setWidget(m_view);
@@ -209,17 +214,18 @@ void BinUnitsView::contextMenuEvent(QContextMenuEvent *event)
         m_model->setTargetFilePath(item.row(), sourceFilePath);
     else if (result==setTarget)
     {
-        KUrl targetFileUrl=KFileDialog::getOpenFileName(Project::instance()->projectDir(),
-                                        "*."+QFileInfo(sourceFilePath).completeSuffix(),this);
-        if (!targetFileUrl.isEmpty())
-            m_model->setTargetFilePath(item.row(), targetFileUrl.toLocalFile());
+        QString targetFilePath=QFileDialog::getOpenFileName(this, QString(), Project::instance()->projectDir());
+        if (!targetFilePath.isEmpty())
+            m_model->setTargetFilePath(item.row(), targetFilePath);
     }
     event->accept();
 }
 
 void BinUnitsView::mouseDoubleClicked(const QModelIndex& item)
 {
+#ifndef NOKDE
     //FIXME child processes don't notify us about changes ;(
     if (item.column()<BinUnitsModel::Approved)
         new KRun(Project::instance()->absolutePath(item.data().toString()),this);
+#endif
 }
